from django.contrib.admin.views.main import ChangeList, PAGE_VAR, ERROR_FLAG
from django.contrib.admin.views.main import ALL_VAR, ORDER_VAR, ORDER_TYPE_VAR, SEARCH_VAR, IS_POPUP_VAR
from django.utils.formats import get_format
from django.contrib.admin.options import IncorrectLookupParameters
from django.db import models
from django.utils.encoding import force_unicode, smart_str
import operator, time, re, datetime
from django.utils.translation import ugettext

class JChangeList(ChangeList):
    def __init__(self, request, model, list_display, list_display_links, list_filter, date_hierarchy, search_fields, list_select_related, list_per_page, list_editable, model_admin):
        self._request = request
        super(JChangeList, self).__init__(request, model, list_display, list_display_links,
                                          list_filter, date_hierarchy, search_fields,
                                          list_select_related, list_per_page, list_editable, model_admin)

        # Cambio il titolo della pagina se viene aggiunto il parametro list_title
        self.title = ugettext('List %s') % force_unicode(self.opts.verbose_name_plural)
        if hasattr(self.model_admin, 'list_title'):
            self.title = self.model_admin.list_title
        self.params = request.GET.copy()

    def get_query_set(self):
        #########################################################
        # Overrides default ordering if default_group_by is set.
        #########################################################
        self.params = self._request.GET.copy()
        if PAGE_VAR in self.params:
            del self.params[PAGE_VAR]
        if ERROR_FLAG in self.params:
            del self.params[ERROR_FLAG]

        lookup_params = self.params.copy()
        groupby = None
        orderby = None

        # Se trovo grouby nella request elimino dal dizionario self.params
        # la chiave groupby in modo che django non faccia errori nel filter del qs
        if lookup_params.has_key('groupby'):
            del self.params['groupby']
            groupby = lookup_params['groupby']
        elif hasattr(self.model_admin, 'default_group_by'):
            groupby = self.model_admin.default_group_by

        if groupby:
            # Se il default_group_by e' una funzione la chiamo e vado a
            # recuperare l'attributo admin_order_field per fare l'ordinamento
            # vero e proprio
            try:
                f = self.lookup_opts.get_field(groupby)
            except models.FieldDoesNotExist:
                # See whether field_name is a name of a non-field
                # that allows sorting.
                try:
                    if callable(groupby):
                        attr = groupby
                    elif hasattr(self.model_admin, groupby):
                        attr = getattr(self.model_admin, groupby)
                    else:
                        attr = getattr(self.model, groupby)
                    groupby = attr.admin_order_field
                except AttributeError:
                    pass
            else:
                groupby = f.name

        qs = self.original_get_query_set()

        # Dopo aver fatto filtrare a Django il queryset rimetto il parametro groupby nel dizionario
        # self.params di modo che venga aggiunto nell'href' degli ordinamenti
        if lookup_params.has_key('groupby'):
            self.params['groupby'] = lookup_params['groupby']

        # Se trovo groupby nella request uso questo come groupby, saltando quello di default
        orderfields = None
        if self.order_field:
            orderby = '%s%s' % ((self.order_type == 'desc' and '-' or ''), self.order_field)

        if groupby and self.order_field and groupby == self.order_field:
            groupby = orderby

        if groupby and orderby:
            if type(groupby) == type(()):
                groupby = list(groupby)
                groupby.append(orderby)
                qs = qs.order_by(*groupby)
            else:
                qs = qs.order_by(groupby, orderby)
        elif groupby:
            if type(groupby) == type(()):
                qs = qs.order_by(*groupby)
            else:
                qs = qs.order_by(groupby)
            #qs = qs.order_by(groupby)

        return qs


    def original_get_query_set(self):
        qs = self.root_query_set
        lookup_params = self.params.copy() # a dictionary of the query string
        for i in (ALL_VAR, ORDER_VAR, ORDER_TYPE_VAR, SEARCH_VAR, IS_POPUP_VAR):
            if i in lookup_params:
                del lookup_params[i]

        ############################################################
        # INIZIO PARTE MODIFICATA PER GESTIONE FILTRI
        ############################################################
        formats_date = get_format('DATE_INPUT_FORMATS')
        for param in lookup_params.keys():
            is_date = False
            correct_date = None
            for format_date in formats_date:
                if isinstance(lookup_params[param], datetime.datetime) or isinstance(lookup_params[param], datetime.date):
                    is_date = True
                else:
                    regexp = format_date.replace("%d", "\d{2}").replace("%m", "\d{2}").replace("%y", "\d{2}").replace("%Y", "\d{4}")
                    is_date = re.search("^%s$" % regexp, lookup_params[param])
                if is_date:
                    try:
                        correct_date = time.strptime(lookup_params[param], format_date)
                        lookup_params[param] = datetime.date(correct_date.tm_year,
                                                             correct_date.tm_mon,
                                                             correct_date.tm_mday)

                        # Se nel filtro delle date sono presenti le parole chiavi range_from
                        # e/o range_to allora gestisco in automatico il filtro range
                        if param.find("__range_from") >= 0:
                            nome_campo = param.replace("__range_from", "")
                            qs = qs.filter(**{str('%s__gte' % nome_campo) : lookup_params[param]})
                            del lookup_params[param]

                        if param.find("__range_to") >= 0:
                            nome_campo = param.replace("__range_to", "")
                            qs = qs.filter(**{str('%s__lte' % nome_campo) : lookup_params[param] + datetime.timedelta(days=1)})
                            del lookup_params[param]

                        break
                    except:
                        continue

        search_form = None
        if hasattr(self.model_admin, 'get_search_form'):
            search_form = self.model_admin.get_search_form()
        else:
            if hasattr(self.model_admin, 'search_form'):
                search_form = self.model_admin.search_form

        if search_form and hasattr(search_form, 'change_search_filter'):
            lookup_params, qs = search_form().change_search_filter(lookup_params, qs)
        ############################################################
        # FINE INIZIO PARTE MODIFICATA PER GESTIONE FILTRI
        ############################################################

        for key, value in lookup_params.items():
            if not isinstance(key, str):
                # 'key' will be used as a keyword argument later, so Python
                # requires it to be a string.
                del lookup_params[key]
                lookup_params[smart_str(key)] = value

            # if key ends with __in, split parameter into separate values
            if key.endswith('__in'):
                lookup_params[key] = value.split(',')

            # if key ends with __isnull, special case '' and false
            if key.endswith('__isnull'):
                if value.lower() in ('', 'false'):
                    lookup_params[key] = False
                else:
                    lookup_params[key] = True

        # Apply lookup parameters from the query string.
        try:
            qs = qs.filter(**lookup_params)
        # Naked except! Because we don't have any other way of validating "params".
        # They might be invalid if the keyword arguments are incorrect, or if the
        # values are not in the correct type, so we might get FieldError, ValueError,
        # ValicationError, or ? from a custom field that raises yet something else
        # when handed impossible data.
        except:
            raise IncorrectLookupParameters

        # Use select_related() if one of the list_display options is a field
        # with a relationship and the provided queryset doesn't already have
        # select_related defined.
        if not qs.query.select_related:
            if self.list_select_related:
                qs = qs.select_related()
            else:
                for field_name in self.list_display:
                    try:
                        f = self.lookup_opts.get_field(field_name)
                    except models.FieldDoesNotExist:
                        pass
                    else:
                        if isinstance(f.rel, models.ManyToOneRel):
                            qs = qs.select_related()
                            break

        # Set ordering.
        if self.order_field:
            qs = qs.order_by('%s%s' % ((self.order_type == 'desc' and '-' or ''), self.order_field))

        # Apply keyword searches.
        def construct_search(field_name):
            if field_name.startswith('^'):
                return "%s__istartswith" % field_name[1:]
            elif field_name.startswith('='):
                return "%s__iexact" % field_name[1:]
            elif field_name.startswith('@'):
                return "%s__search" % field_name[1:]
            else:
                return "%s__icontains" % field_name

        if self.search_fields and self.query:
            for bit in self.query.split():
                or_queries = [models.Q(**{construct_search(str(field_name)): bit}) for field_name in self.search_fields]
                qs = qs.filter(reduce(operator.or_, or_queries))
            for field_name in self.search_fields:
                if '__' in field_name:
                    qs = qs.distinct()
                    break

        return qs
