import datetime
from django.conf import settings
from django import template
from django.core.urlresolvers import reverse
from django.utils.dateformat import format
from django.utils.dates import WEEKDAYS, WEEKDAYS_ABBR

from datetime import datetime, time, date, timedelta

from jumbo.apps.calendar.utils import *
#from agenda.models import Appointment

from itertools import groupby
from operator import itemgetter


weekday_names = []
weekday_abbrs = []

# The calendar week starts on Monday
for i in range(7):
    weekday_names.append( WEEKDAYS[i] )
    weekday_abbrs.append( WEEKDAYS_ABBR[i] )

register = template.Library()

@register.inclusion_tag("calendar/tags/_year_table.html",  takes_context=True)
def year_table(context, period):
    context['day_names']  = weekday_names
    return context

#@register.inclusion_tag("calendar/tags/_month_table.html",  takes_context=True)
#def month_table(context, period):
#    context['day_names']  = weekday_names
#    return context

#@register.inclusion_tag("calendar/tags/_week_table.html",  takes_context=True)
#def week_table(context, period):
#    context['day_names']  = weekday_names
#    return context

@register.inclusion_tag("calendar/tags/_day_table.html",  takes_context=True)
def day_table(context, period):
    return context

@register.inclusion_tag("calendar/tags/_prevnext.html")
def prevnext(target, period, fmt=None, url_name=None):
    if fmt is None:
        fmt = settings.DATE_FORMAT
    context = {
        'period' : period,
        'period_name': format(period.day, fmt),
        'target':target,
        'url_name':url_name
    }
    return context

#@register.inclusion_tag("calendar/tags/_events.html",  takes_context=True)
#def get_events(context, day, url_name=None):
#    context = {
#        'd' : day,
#        'url_name': url_name
#    }    
#    return context

@register.simple_tag
def day_classes(day, period):
    classes = "day"
    if day.is_hide(period):
        classes += " extra"
    elif day.is_busy():
        classes += " busy"
    else:
        classes += " free"
    if day.is_today():
        classes += " today"
    if day.is_holiday():
        classes += " holiday"
    return classes

@register.simple_tag
def app_url(obj):
    return reverse('admin:%s_%s_detail' % (obj._meta.app_label,  obj._meta.object_name.lower()), obj.id)

@register.simple_tag
def period_url(target, period, url_name):
    return reverse(url_name, kwargs={'type_list': target, 'day': period.day.strftime('%Y%m%d')})

@register.simple_tag
def prev_url(target, period, url_name):
    return reverse(url_name, kwargs={'type_list': target, 'day': period.prev().day.strftime('%Y%m%d')})

@register.simple_tag
def next_url(target, period, url_name):
    return reverse(url_name, kwargs={'type_list': target, 'day': period.next().day.strftime('%Y%m%d')})

@register.inclusion_tag("calendar/tags/_count_events.html", takes_context=True)
def get_appointments_count(context, day):
    e = len(day.events)

    if e==0:
        e = ""
    elif e==1:
        e = "%s Object" % (e,)
    else:
        e = "%s Objects" %(e,)

    context = {
        'd' : day,
        'e' : e
    }   
    return context

@register.inclusion_tag("calendar/tags/_daily_grid.html", takes_context=True)
def daily_grid(context, period):

    t = TimeGrid()
    
    r = t.get_range(period.events)
    
    context = {
        'grid' : r,
    }    
    return context

@register.inclusion_tag("calendar/tags/_daily_table.html", takes_context=True)
def daily_table(context, period):
    
    dict = {}
    t = TimeGrid()

    WIDTH = int(200)        # Larghezza (massima) della cella di un appuntamento
    HEIGHT = int(50)        # Altezza di uno slot di un'ora
    MARGIN_LEFT = int(100)  # Scostamento dalla colonna sinistra
    TABLE_WIDTH = int(890)  # Larghezza della tabella
    MIN_HEIGHT = int(1)     # Altezza minima di una cella (1 per un'ora, 0,5 per mezz'ora...)
 
    period.events.sort(key=lambda x: x.time_begin)

    l_cs = []
    max_position = 0
    
    if period.events:
        day_range = t.get_range(period.events)
        
        # CICLO LE ORE NEL GIORNO
        for c in day_range:
            # CREO UN CALENDAR SHEET PER OGNI ORA
            cs = CalendarSheet(c)
            dict[c] = cs
          
        # CICLO LE ORE NEL GIORNO
        for c in day_range:
            # CREO UN CALENDAR SHEET PER OGNI ORA
            cs = dict[c]
            l_cs.append(cs)
            # CICLO GLI APPUNTAMENTI NEL PERIOD
            for e in period.events:
                e.width = WIDTH
                e.start = int(e.time_begin.strftime("%H"))
                e.end = int(e.time_end.strftime("%H"))
            # ASSEGNO GLI APPUNTAMENTI A REAL_EVENT SOLO NEL CASO IN CUI INIZINO NELL'ORA CICLATA
            # E ANCHE A FAKES_EVENT
                if c==e.start:
                    top = (e.start-day_range[0])
                    height = e.end-e.start
                    if height>1:
                        diff = ((int(e.time_end.strftime("%M"))-(int(e.time_begin.strftime("%M"))))/60.0)
                        height = height+diff
                    else:
                        height = MIN_HEIGHT
                    e.top = (top*HEIGHT)+int((HEIGHT*(int(e.time_begin.strftime("%M"))))/60.0)
                    e.height = int(height*HEIGHT)
                    #print e.height
                    cs.add_real_event(e)
                    # IL POSIZIONAMENTO DEL PRIMO FAKE_EVENT DOVRA' ESSERE 
                    # QUELLO CHE L'APPUNTAMENTO MANTIENE ANCHE NELLE ORE IN CUI CONTINUA
                    position = cs.add_fake_event(e)
                    if max_position<position:
                        max_position=position
                    e.left = position*WIDTH
                    e.position = position    
                    app_range = range(c+1,e.end+1)
                    for app_hours in app_range:
                        # ASSEGNO GLI APPUNTAMENTI A FAKES_EVENT ANCHE PER TUTTE LE ORE
                        # IN CUI L'APPUNTAMENTO CONTINUA
                        cs_next = dict[app_hours]
                        cs_next.add_fake_event(e, position)
                        e.left = position*WIDTH
                        e.position = position
        
        context = {
            'dict' : l_cs,
            'ML' : MARGIN_LEFT,
            'max' : max_position+1,
            'dynamic_width': (TABLE_WIDTH/(max_position+1))
        }
   
        return context

@register.simple_tag
def dynamic_margin_left(margin_left, dynamic_width, position):
    return margin_left+(dynamic_width*position)