from django.utils.translation import ugettext_lazy as _
from django.contrib import admin
from jumbo.admin.options import OrderedModelAdmin
from jumbo.forms.models import AdminModelForm
from jumbo.apps.menu.models import Menu, MenuTranslation, MenuIcon, Category

class CategoryAdminForm(AdminModelForm):
    class Meta:
        model = Category
class CategoryAdmin(OrderedModelAdmin):
    model = Category
    form = CategoryAdminForm
    search_fields = ("status", "name",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering","name",)
    fieldsets = (
        (_('logs admin'), {'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        (_('visualization admin'), {'fields': ('ordering',), 'classes': ('collapse',),}),
        (_('general admin'), {'fields': ('status', 'default'),}),
        (None, {"fields": ("name",),}),
    )
admin.site.register(Category, CategoryAdmin)

class MenuIconAdminInline(admin.TabularInline):
    class Meta:
        verbose_name = _('Icon')
        verbose_name_plural = _('Icons')
    model = MenuIcon
    extra = 2
    fields = ('type', 'custom', 'icon',)

class MenuTranslationAdminInline(admin.TabularInline):
    model = MenuTranslation
    extra = 3
    fields = ('language', 'name',)

class MenuAdmin(admin.ModelAdmin):
    save_on_top = True
    fieldsets = (
        (_('Menu'), {'fields': ('name', ('parent', 'category',), 'caption', 'url', 'open_choices', 'template', 'ordering',),},),
        (_('User Permission'), {'fields': ('permission',),},),
    )
    ordering = ('category', 'ordering',)
    search_fields = ('name', 'caption', 'parent',)
    list_display = ('category', 'full_name', 'permission', 'ordering')
    list_display_links = ('full_name',)
    inlines = [MenuTranslationAdminInline, MenuIconAdminInline,]
admin.site.register(Menu, MenuAdmin)

