import re, sys

from django.core.management.base import BaseCommand
from django.core.management import call_command
from django.db import transaction
from django.conf import settings
from django.utils.importlib import import_module
from optparse import make_option

APPLICATIONS = settings.INSTALLED_APPS

try:
    from jumbo.apps.menu.models import Menu, MenuTranslation, Category
    from jumbo.apps.i18n.models import Language
except:
    print "You must have jumbo.apps.menu installed."
    sys.exit(0)

class Command(BaseCommand):
    help = "(Re)create menu for all installed apps"
    pattern = re.compile('^(?P<offset> *)(?P<data>.+)')
    ordering = 0

    option_list = BaseCommand.option_list + (
        make_option('-f', '--file', dest='file',
                    help='If provide use this file to load the entire menu.'),
    )
    args = '[optional file path]'

    def handle(self, *args, **options):
        transaction.enter_transaction_management()
        transaction.managed()

        # Delete old menus
        print 'Delete old menus'
        for m in MenuTranslation.objects.all(): m.delete()
        for m in Menu.objects.all(): m.delete()
        for m in Category.objects.all(): m.delete()

        self.category = Category()
        self.category.name = 'TOP'
        self.category.save()

        use_file = options.get('file', False)
        if use_file:
            self.filename = use_file
            f = open(self.filename, 'r')
            self.create_menu(f)
            transaction.commit()
        else:
            dirs_list = []

            for module in APPLICATIONS:
                tmp = import_module(module)
                if tmp.__file__: elements = tmp.__file__.split('/')
                elements.pop()
                dirs_list.append('/'.join(elements))

            for d in dirs_list:
                print 'Import Menus Running for App: %s' % d.split('/').pop()
                self.filename = '%s/menu.txt' % d

                try:
                    f = open(self.filename, 'r')
                except IOError, e:
                    continue

                self.create_menu(f)
                transaction.commit()

    def create_menu(self, f):
        line_number = 0
        comment_pattern = re.compile('^\s*#')
        whitespaces_pattern = re.compile('^\s*$')
        self.father_menu = None

        for line in f.readlines():
            line_number += 1
            self.ordering += 1
            # comment
            if comment_pattern.match(line) or whitespaces_pattern.match(line):
                continue
            try:
                self.parse_line(line, line_number)
            except Exception, e:
                print "Error in file %s at line %s. Error : %s" % (self.filename, line_number, e)
                transaction.rollback()
                sys.exit(0)

    def parse_line(self, line, line_number):
        result = self.pattern.match(line)
        offset = len(result.group('offset'))
        rest = offset % 4

        if (rest > 0):
            sys.exit( "Indentation Error (%s spaces) %s:%s\n%s" % (
                offset, self.filename, line_number, line ) )
        else:
            current_level = offset / 4
            data   = result.group('data')
            ldata = data.split('->')
            # Inserisco i menu con i nomi di default
            data = ldata[0]
            elements = data.split(',')
            arguments = len(elements)

            menu = Menu()
            menu.status = 1
            menu.category = self.category
            menu.name = elements[0].strip()
            if len(elements) > 1:
                menu.caption = elements[1].strip()
            if len(elements) > 2:
                menu.url = elements[2].strip()
            if len(elements) > 3:
                menu.permission = elements[3].strip()

            menu.ordering = self.ordering

            menu.name = menu.name

            # il terzo parametro e' l'ordinamento. Se l'utente lo mette
            # sovrascrivo l'ordinamento di default con quello dell'utente
            if len(elements) > 4:
                menu.open_choices = elements[4].strip()

            if current_level == 0:
                self.father_menu = menu
            elif current_level > 1:
                menu.parent = self.father_menu

            menu.save()

            # Se ci sono, inserisco le traduzioni
            tr = []
            if len(ldata) > 1:
                t = ldata[1].strip()
                translation = eval(t)

                for t in translation:
                    lang, text = t

                    try:
                        language = Language.objects.get(code=lang)
                        mt = MenuTranslation()
                        mt.language = language
                        mt.menu = menu
                        mt.name = text
                        mt.save()
                        tr.append(mt)
                    except Exception, e:
                        continue

            menu.save()

