from django import template
from django.conf import settings
from django.db.models import Q
from jumbo.shortcuts import render_to_string
from django.utils.safestring import mark_safe
from jumbo.apps.menu.models import Menu, MenuIcon

register = template.Library()

@register.inclusion_tag('menu/tags/menu.html', takes_context=True)
def show_menu(context, category, template_name, app_label=None, node=None, url='/', level=None):
    request = context['request']
    if node:
        menu = Menu.objects.filter(parent=node).order_by('ordering')
        if app_label:
            menu = menu.filter(caption=app_label)
    else:
        menu = Menu.objects.filter(category__name=category, parent__isnull=True).order_by('ordering')
    data = []
    for item in menu:
        if item.permission and not request.user.has_perm(item.permission):
            continue
        data.append(item)
    if level is None:
        level = 0
    else:
        level = level+1
    render = render_to_string(template_name, request=request, app_label=app_label, menu=data, url=url, level=level)
    context['render'] = render
    return context

class GetMenuIconNode(template.Node):
    def __init__(self, menu, type, name):
        self.menu = template.Variable(menu)
        self.type = template.Variable(type)
        self.name = name

    def render(self, context):
        menu = self.menu.resolve(context)
        type = str(self.type.resolve(context))
        try:
            context[self.name] = menu.icons.get(Q(type=type)|Q(custom=type)).icon
        except MenuIcon.DoesNotExist:
            context[self.name] = None
        return ''

@register.tag
def get_menu_icon(parser, token):
    """
    This will store the icon menu

    Usage::

        {% get_menu_icon menu 'type' as icon %}
        {{ icon.url }}

    """
    args = token.split_contents()
    if len(args) != 5 or args[3] != 'as':
        raise TemplateSyntaxError, "'get_menu_icon' requires 'as variable' (got %r)" % args
    return GetMenuIconNode(args[1], args[2], args[4])

@register.simple_tag
def icon_menu(menu, type):
    prefix_url = '%s%s' % (getattr(settings, 'PREFIX_URL_MENU', ''), url)
    return mark_safe(prefix_url.replace('//', '/'))

@register.simple_tag
def url_menu(url):
    prefix_url = '%s%s' % (getattr(settings, 'PREFIX_URL_MENU', ''), url)
    return mark_safe(prefix_url.replace('//', '/'))



