from django.conf import settings
from django.utils.translation import ugettext as _
from jumbo.core.urlresolvers import reverse
from jumbo.utils.functions import get_settings
from jumbo.middleware.thread_local import get_current_user
from jumbo.apps.project.models import Project

class ProjectList(object):
    model = Project
    list_display = ['get_status_icon', 'organization', 'link_project', 'get_date_start', 'get_date_end', 'link_ticket_project', 'link_document_project', 'get_invoicerows_link']
    default_order_by= 'name'

    def get_status_icon(self, result):
        return "<img title='%(name_status)s' src='%(url)sjumbo/img/status_%(status)s.gif'/>" % {
            'name_status':  result.get_status_display(),
            'url':          settings.MEDIA_URL,
            'status':       result.status
        }
    get_status_icon.short_description = _("Status")

    def get_date_start(self, result):
        return result.date_start.strftime("%d/%m/%Y")
    get_date_start.short_description = _('Start Date')

    def get_date_end(self, result):
        return result.date_end.strftime("%d/%m/%Y")
    get_date_end.short_description = _('End Date')

    def get_invoicerows_link(self, result):
        link = ""
        num = result.invoicerows.count()
        if num > 0:
            link = """<a href="%(reverse_url)s" rel="#overlay">%(num_rows)s</a>""" % {
                'reverse_url': reverse('project-project-total_invoicerows', result.id),
                'num_rows': num,
            }

        return "%s" % link
    get_invoicerows_link.short_description = _('IR')

    def link_project(self, result):
        return """<a href="%(url)s">%(detail)s</a>""" % {
            'url':      reverse("project-project-edit", result.id),
            'detail':   result.name
        }

    def link_ticket_project(self, result):
        try:
            r = result.ticketproject
            icon = "green_light.gif"
            title_icon = "yes"

        except:
            icon = "red_light.gif"
            title_icon = "no"

        return """<a href="%(reverse_url)s" onclick="jshowAddAnotherPopup(this, '', 300, 800, 100, 200);return false;"><img title="%(title)s" src="%(url)sjumbo/img/%(icon)s"/></a>""" % {
            'reverse_url':      reverse('ticket-project-edit', result.id),
            'title':            title_icon,
            'url':              settings.MEDIA_URL,
            'icon':             icon,
        }
    link_ticket_project.short_description = _('Ticket')

    def link_document_project(self, result):
        try:
            r = result.documentproject
            icon = "green_light.gif"
            title_icon = "yes"

        except:
            icon = "red_light.gif"
            title_icon = "no"

        return """<a href="%(reverse_url)s" onclick="jshowAddAnotherPopup(this, '', 300, 800, 100, 200);return false;"><img title="%(title)s" src="%(url)sjumbo/img/%(icon)s"/></a>""" % {
            'reverse_url':      reverse('document-project-edit', result.id),
            'title':            title_icon,
            'url':              settings.MEDIA_URL,
            'icon':             icon,
        }
    link_document_project.short_description = _('Document')
