# -*- coding: utf-8 -*-
import sys, logging, time, datetime
import hashlib, base64
from hashlib import md5

from suds.client import Client
from suds.xsd.doctor import Import, ImportDoctor
from suds.transport.http import HttpAuthenticated


URL_TOL = 'http://sptest.posteitaliane.it/TelegrammaExtranet/WsTOL.svc?WSDL'
URL_ROL = 'http://sptest.posteitaliane.it/ROLGC/RolService.svc?WSDL'
URL_LOL = 'http://sptest.posteitaliane.it/LOLGC/LolService.svc?WSDL'


class ExceptionPosteSoapClient(Exception):
    def __init__(self, ceresult):
        super(ExceptionPosteSoapClient, self).__init__()
        self.ceresult = ceresult
        self.cer_code = ceresult._Code
        self.cer_type = ceresult._Type
        self.cer_description = ceresult._Description

class PosteSoapClient(object):
    pass

class ROLSoapClient(PosteSoapClient):
    def __init__(self):
        super(ROLSoapClient, self).__init__()
        imp = Import('http://www.w3.org/2001/XMLSchema')
        imp.filter.add("http://ComunicazioniElettroniche.ROL.WS")
        imp.filter.add("htp://ComunicazioniElettroniche.XOL")
        doctor = ImportDoctor(imp)
        self.client = Client(URL_ROL, doctor=doctor,
                                 username='H2HSTG21', password='Cestg021')
        self.client.set_options(
                location="http://sptest.posteitaliane.it/ROLGC/RolService.svc")
        
    def recupera_id_richiesta(self):
        result = self.client.service.RecuperaIdRichiesta()
        if result.CEResult._Type == "I":
            return result.IDRichiesta
        raise ExceptionPosteSoapClient(result.CEResult)
    
    def valida_destinatari(self, idrichiesta, destinatari):
        result = self.client.service.ValidaDestinatari(IDRichiesta=idrichiesta,
                                                       Destinatari=destinatari)
        if result.CEResult._Type == "I":
            return result.DatiDestinatari
        raise ExceptionPosteSoapClient(result.CEResult)
    
    def invio(self, idrichiesta, cliente, rolsubmit):
        result = self.client.service.Invio(IDRichiesta=idrichiesta,
                                           Cliente=cliente,
                                           ROLSubmit=rolsubmit)
        if result.CEResult._Type == "I":
            return result
        raise ExceptionPosteSoapClient(result.CEResult)
    
    def recupera_dcs(self, richiesta):
        result = self.client.service.RecuperaDCS(Richiesta=richiesta)
        if result.CEResult._Type == "I":
            return result.ROLResponse
        raise ExceptionPosteSoapClient(result.CEResult)
    
class PosteSoapFactory(object):
    @staticmethod
    def encode_file(filename):
        encoded_data = base64.b64encode(open(filename, 'rb').read())
        strg = ''
        for i in xrange((len(encoded_data)/40)+1):
            strg += encoded_data[i*40:(i+1)*40]
        img = strg
        return (img, md5(file(filename).read()).hexdigest().upper())

class ROLSoapFactory(PosteSoapFactory):
    def __init__(self):
        super(ROLSoapFactory, self).__init__()
        imp = Import('http://www.w3.org/2001/XMLSchema')
        imp.filter.add("http://ComunicazioniElettroniche.ROL.WS")
        imp.filter.add("htp://ComunicazioniElettroniche.XOL")
        doctor = ImportDoctor(imp)
        self.client = Client(URL_ROL, doctor=doctor,
                                 username='H2HSTG21', password='Cestg021')
        self.client.set_options(
                location="http://sptest.posteitaliane.it/ROLGC/RolService.svc")
        
    def create_destinatario(self, dug=' ', toponimo=' ', numero_civico=' ',
                            esponente=' ', zona=' ', tipo_indirizzo=' ',
                            stato=' ', telefono=' ', forza_destinazione=' ',
                            casella_postale=' ', ufficio_postale=' ',
                            provincia=' ', complemento_nominativo=' ',
                            ragione_sociale=' ', cognome=' ', nome=' ',
                            frazione=' ', citta=' ', complemento_indirizzo=' ',
                            cap=' ', id_ricevuta=' ', id_destinatario=' '):
        indirizzo = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Indirizzo')
        indirizzo._DUG = dug
        indirizzo._Toponimo = toponimo
        indirizzo._NumeroCivico = numero_civico
        indirizzo._Esponente = esponente
        nominativo = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Nominativo')
        nominativo.Indirizzo = indirizzo
        nominativo._Zona = zona
        nominativo._TipoIndirizzo = tipo_indirizzo
        nominativo._Stato = stato
        nominativo._Telefono = telefono
        nominativo._ForzaDestinazione = forza_destinazione
        nominativo._CasellaPostale = casella_postale
        nominativo._UfficioPostale = ufficio_postale
        nominativo._Provincia = provincia
        nominativo._ComplementoNominativo = complemento_nominativo
        nominativo._RagioneSociale = ragione_sociale
        nominativo._Cognome = cognome
        nominativo._Nome = nome
        nominativo._Frazione = frazione
        nominativo._Citta = citta
        nominativo._ComplementoIndirizzo = complemento_indirizzo
        nominativo._CAP = cap
        destinatario = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Destinatario')
        destinatario.Nominativo = nominativo
        destinatario._IdRicevuta = id_ricevuta
        destinatario._IdDestinatario = id_destinatario
        return destinatario
    
    def create_array_of_destinatario(self, destinatari):
        aod = self.client.factory.create('ArrayOfDestinatario')
        for d in destinatari:
            aod.Destinatario.append(d)
        return aod
    
    def create_mittente(self, dug=' ', toponimo=' ', numero_civico=' ',
                        esponente=' ', zona=' ', tipo_indirizzo=' ', stato=' ',
                        telefono=' ', forza_destinazione=' ',
                        casella_postale=' ', ufficio_postale=' ', provincia=' ',
                        complemento_nominativo=' ', ragione_sociale=' ',
                        cognome=' ', nome=' ', frazione=' ', citta=' ',
                        complemento_indirizzo=' ', cap=' '):
        indirizzo_mittente = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Indirizzo')
        indirizzo_mittente._DUG = dug
        indirizzo_mittente._Toponimo = toponimo
        indirizzo_mittente._NumeroCivico = numero_civico
        indirizzo_mittente._Esponente = esponente
        nominativo_mittente = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Nominativo')
        nominativo_mittente.Indirizzo = indirizzo_mittente
        nominativo_mittente._Zona = zona
        nominativo_mittente._TipoIndirizzo = tipo_indirizzo
        nominativo_mittente._Stato = stato
        nominativo_mittente._Telefono = telefono
        nominativo_mittente._ForzaDestinazione = forza_destinazione
        nominativo_mittente._CasellaPostale = casella_postale
        nominativo_mittente._UfficioPostale = ufficio_postale
        nominativo_mittente._Provincia = provincia
        nominativo_mittente._ComplementoNominativo = complemento_nominativo
        nominativo_mittente._RagioneSociale = ragione_sociale
        nominativo_mittente._Cognome = cognome
        nominativo_mittente._Nome = nome
        nominativo_mittente._Frazione = frazione
        nominativo_mittente._Citta = citta
        nominativo_mittente._ComplementoIndirizzo = complemento_indirizzo
        nominativo_mittente._CAP = cap        
        mittente = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Mittente')
        mittente.Nominativo = nominativo_mittente
        return mittente
    
    def create_rol_submit(self, mittente, destinatari, documento, inserto=' ',
                          secur_paper='false', inserisci_mittente='false',
                          data_stampa=datetime.datetime.now(),
                          firma_elettronica='false', archiviazione='false',
                          dpm='false'):
        rs = self.client.factory.create('ROLSubmit')
        rs.Mittente = mittente
        rs.Destinatari = destinatari
        rs.NumeroDestinatari = str(len(destinatari)/6)
        opzioni = self.client.factory.create('Opzioni')
        opzioni._SecurPaper = secur_paper
        opzioni._InserisciMittente = inserisci_mittente
        opzioni._DataStampa = data_stampa
        opzioni._FirmaElettronica = firma_elettronica
        opzioni._Archiviazione = archiviazione
        opzioni._DPM = dpm
        inserti = self.client.factory.create('Inserti')
        inserti._InserisciMittente = inserisci_mittente
        inserti._Inserto = " "
        opzioni.Inserti = inserti
        rs.Opzioni = opzioni
        rs.Documento = documento
        return rs
    
    def create_documento(self, filename):
        documento = self.client.factory.create('{http://ComunicazioniElettroniche.XOL}Documento')
        img, emmedic = ROLSoapFactory.encode_file(filename)
        documento.Firmatari = " "
        documento.Immagine = img
        documento.MD5 = emmedic
        documento._TipoDocumento = "pdf"
        return documento
    
    def create_richiesta(self, idrichiesta, guidutente):
        richiesta = self.c.factory.create('{http://ComunicazioniElettroniche.XOL}Richiesta')
        richiesta.IDRichiesta = idrichiesta
        richiesta.GuidUtente = guidutente
        return richiesta
            
