# -*- coding: utf-8 -*-
'''
Created on 6/dic/2011

@author: simone cittadini
'''
import sys, logging, time
import hashlib, base64
from hashlib import md5

from suds.client import Client
from suds.xsd.doctor import Import, ImportDoctor
from suds.transport.http import HttpAuthenticated

from unittest import TestCase

from poste.webservice import ROLSoapClient, ROLSoapFactory, ExceptionPosteSoapClient

DEBUG = True
URL_TOL = 'http://sptest.posteitaliane.it/TelegrammaExtranet/WsTOL.svc?WSDL'


class TestPosteItalianeTOL(TestCase):
    """
    Casi di test che coprono il documento richiesto da poste italiane
    per l'attivazione del canale h2h (telegramma).
    """

    def setUp(self):
        if DEBUG:
            logging.basicConfig(level=logging.INFO)
            logging.getLogger('suds').setLevel(logging.ERROR)
            logging.getLogger('suds.client').setLevel(logging.ERROR)
            logging.getLogger('suds.transport').setLevel(logging.ERROR)
        imp = Import('http://www.w3.org/2001/XMLSchema')
        imp.filter.add("http://ComunicazioniElettroniche.TOL.WS")
        doctor = ImportDoctor(imp)
        self.c = Client(URL_TOL, doctor=doctor, username='H2HSTG21', password='Cestg021')
        self.c.set_options(location="http://sptest.posteitaliane.it/TelegrammaExtranet/WsTOL.svc")
        if DEBUG:
            print self.c

    def test_f0001_03(self):
        # verifica destinatario  non valido
        result = self.c.service.GetIdRequest()
        # recuperto l'id richiesta
        idr = result
        # fornisco un destinatario con indirizzo valido e nome-cognome non valido
        r = self.c.factory.create('Recipient')
        r.destinatario.CAP = '20092'
        r.destinatario.Citta = 'CINISELLO BALSAMO'
        r.destinatario.Cognome = 'CittadiniCittadiniCittadiniCittadini'
        r.destinatario.Indirizzo = 'via casignolo, 4'
        r.destinatario.Nome = 'SimoneSimoneSimoneSimone'
        r.destinatario.RagioneSociale = ''
        r.destinatario.Stato = ''
        r.destinatario.Telefono = ''
        # verifico i destinatari
        result = self.c.service.RecipientValidation(merda=r, idRequest=idr)
        self.assertEqual("E", result.Result.ResType)
        self.assertEqual("Unexpected error has occurred.The request has not been processed", result.Result.Description )
        # sottometto il telegramma
        # ?

    def test_f0001_03_sd(self):
        "verifica destinatario  non valido"

#        self.c = setUp_()
        result = self.c.service.GetIdRequest()
        # recuperto l'id richiesta
        idr = result
        # fornisco un destinatario con indirizzo valido e nome-cognome non valido
        r = self.c.factory.create('Recipient')
        r.destinatario.CAP = '20092'
        r.destinatario.Citta = 'CINISELLO BALSAMO'
        r.destinatario.Cognome = 'CittadiniCittadiniCittadiniCittadini'
        r.destinatario.Indirizzo = 'via casignolo, 4'
        r.destinatario.Nome = 'SimoneSimoneSimoneSimone'
        r.destinatario.RagioneSociale = ''
        r.destinatario.Stato = ''
        r.destinatario.Telefono = ''
        # verifico i destinatari
        result = self.c.service.RecipientValidation(recippient=r, idRequest=idr)
        self.assertEqual("E", result.Result.ResType)
        self.assertEqual("Unexpected error has occurred.The request has not been processed", result.Result.Description )
        # sottometto il telegramma
        # ?

 
    def test_f0001_03_debug(self):
        "verifica destinatario  non valido - debug"

        result = self.c.service.GetIdRequest()
        # recuperto l'id richiesta
        idr = result
        # fornisco un destinatario con indirizzo valido e nome-cognome non valido
        r = self.c.factory.create('Recipient')
        r.destinatario.CAP = '20092'
        r.destinatario.Citta = 'CINISELLO BALSAMO'
        r.destinatario.Cognome = 'CittadiniCittadiniCittadiniCittadini'
        r.destinatario.Indirizzo = 'via casignolo, 4'
        r.destinatario.Nome = 'SimoneSimoneSimoneSimone'
        r.destinatario.RagioneSociale = ''
        r.destinatario.Stato = ''
        r.destinatario.Telefono = ''
        # verifico i destinatari
#        result = self.c.service.RecipientValidation(recipient=r, idRequest=idr)
        result = self.c.service.RecipientValidation(recippient=r, idRequest=idr)
        self.assertEqual("E", result.Result.ResType)
        self.assertEqual("Unexpected error has occurred.The request has not been processed", result.Result.Description )
        # sottometto il telegramma
        # ?

