# Django settings for p project.
import os
import socket

from jogging.handlers import DatabaseHandler
import logging

ugettext = lambda s: s

ADMINS = (
    ('Marco Minutoli', 'mminutoli@thundersystems.it'),
    ('Vittorino Parenti', 'vparenti@thundersystems.it'),
)

INTERNAL_IPS = ('127.0.0.1',)
MANAGERS = ADMINS
SERVER_EMAIL = 'jumbo@thundersystems.it'

JUMBO_PATH = __import__('jumbo', {},{},[]).__path__[0]

DATABASE_ENGINE = 'sqlite3'    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
DATABASE_NAME = 'jumbo.db'   # Or path to database file if using sqlite3.
DATABASE_USER = ''             # Not used with sqlite3.
DATABASE_PASSWORD = ''         # Not used with sqlite3.
DATABASE_HOST = ''             # Set to empty string for localhost. Not used with sqlite3.
DATABASE_PORT = ''             # Set to empty string for default. Not used with sqlite3.

EMAIL_HOST = 'localhost'

DEBUG = False
DEFAULT_CHARSET = 'utf-8'

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'Europe/Rome'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'it'
LANGUAGES = (
    ('it', ugettext('Italian')),
    ('en', ugettext('English')),
)

#DATE_FORMAT="d/m/Y"
#TIME_FORMAT="H:i"
#DATETIME_FORMAT="d/m/Y H:i"

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True
USE_L10N = True

USE_THOUSAND_SEPARATOR = True

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = '/static/'
DOCUMENT_URL = '/files/'

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/media/'
# Link per richiedere assistenza
ADMIN_SUPPORT_LINK = "<a href='https://office.thundersystems.it/'>Help</a>"
# Titolo
ADMIN_SITE_NAME = 'Jumbo'
# Link che compaiono nel footer
ADMIN_POWEREDBY_LINK = "<b>Powered by <a href='http://www.thundersystems.it/'>ThunderSystems</a></b>"
ADMIN_FAVICON_URL = MEDIA_URL + 'admin/images/favicon.ico'
ADMIN_THEME_NAME = 'default_970'

# Jumbo static files
JUMBO_MEDIA_ROOT = ''.join([JUMBO_PATH, '/static/'])

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'qgj&d^*=fdptcf-1#kgq4_p^$pzn8^vj+)2-=beo9ch_7)l(9g'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

###### ATTENZIONE ########
# django.middleware.locale.LocaleMiddleware deve essere sempre al 3 posto in questa lista
# perche verra' poi sostuito nei middleware del cms (settings_cms.py).
# Se si cambia la posizione di questo middleware bisognera' modificare anche
# i MIDDLEWARE del cms
MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.middleware.doc.XViewMiddleware',
    'django.middleware.transaction.TransactionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'jumbo.middleware.thread_local.ThreadLocals',
    'jogging.middleware.LoggingMiddleware',
    'lastActivityDate.LastActivityMiddleware.LastActivityMiddleware',
    'jumbo.middleware.maintenance_middleware.MaintenanceMiddleware',
    #'jumbo.middleware.login_middleware.LoginMiddleware',
    #'jumbo.middleware.debug_middleware.DebugFooter',
)

TEMPLATE_DIRS = [
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.

    # sandro: this is silly. PROJECT_PATH was fake was really JUMBO_PATH where filesystem laod
    # does not need to look for. PROJECT_PATH must be set in settings.py
    #''.join([PROJECT_PATH, '/templates/']),
]

DEFAULT_FILE_STORAGE = 'jumbo.core.files.storage.JumboStorage'

# Add jumbo locale path
LOCALE_PATHS = (
    ''.join([JUMBO_PATH, '/locale/']),
)
FORMAT_MODULE_PATH = 'jumbo.formats'

ADMIN_TOOLS_APPS = (
    'admin_tools.theming',
    'admin_tools.dashboard',
    'admin_tools.menu',
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django.contrib.comments',
    'django.contrib.messages',
    'django.contrib.sitemaps',
    'django_extensions',
    'south',
    'jumbo',
    'jumbo.apps.l10n',
    'jumbo.apps.i18n',
    'jumbo.apps.template',
    'jumbo.apps.comments',
    'jumbo.apps.tables',
    'jumbo.apps.dajax',
    'jumbo.apps.abicab',
    'jumbo.apps.exception',
    'jumbo.apps.auth',
    'dajaxice',
    'dajax',
    'jogging',
    'lastActivityDate',
    'facebook'
)

INSTALLED_APPS = ADMIN_TOOLS_APPS + INSTALLED_APPS

# Jumbo relies on these context processors
TEMPLATE_CONTEXT_PROCESSORS = (
    'django.core.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.request',
    'django.contrib.messages.context_processors.messages',
    'jumbo.core.context_processors.media',
    'facebook.context_processors.facebook'
)

AUTHENTICATION_BACKENDS = (
    'facebook.backend.FacebookBackend',
    'jumbo.core.backends.EmailOrUsernameModelBackend',
    'django.contrib.auth.backends.ModelBackend',
)

#############################
# FACEBOOK SETTINGS
#############################
ENABLE_FACEBOOK_LOGIN = False
FACEBOOK_APP_ID = 'XXXXXXXXXX'
FACEBOOK_API_KEY = 'XXXXXXXXXXX'
FACEBOOK_SECRET_KEY = 'XXXXXXXXXXXX'
#############################
# END FACEBOOK SETTINGS
#############################

# Storage backend for message framework
MESSAGE_STORAGE = 'django.contrib.messages.storage.fallback.FallbackStorage'

COMMENTS_APP = 'jumbo.apps.comments'

# DAJAX SETTINGS
DAJAXICE_MEDIA_PREFIX="dajaxice"

# ADMIN TOOLS SETTINGS
ADMIN_TOOLS_INDEX_DASHBOARD = 'jumbo.admin.dashboard.JumboIndexDashboard'
ADMIN_TOOLS_APP_INDEX_DASHBOARD = 'jumbo.admin.dashboard.JumboAppIndexDashboard'
ADMIN_TOOLS_THEMING_CSS = 'admin_tools/css/dashboard.css'
ADMIN_EXTENDED_MENU = 'jumbo.conf.admin_extended_menu.JumboExtendedMenu'
ADMIN_CONTRACT_MENU = 'jumbo.conf.admin_contract_menu.JumboContractMenu'

# TinyMCE Conf
TINYMCE_JS_URL  = '%stiny_mce/tiny_mce.js' % MEDIA_URL
TINYMCE_DEFAULT_CONFIG = {
    "plugins" : "table",
    "theme": "advanced",
    "theme_advanced_buttons1" : "bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,|,styleselect,formatselect,fontselect,fontsizeselect",
    "theme_advanced_buttons2" : "cut,copy,paste,pastetext,pasteword,|,forecolor,backcolor,|,bullist,numlist,|,outdent,indent,blockquote,|,undo,redo,|,link,unlink,anchor,image,code",
    "theme_advanced_buttons3" : "tablecontrols,|,hr,removeformat,visualaid,|,sub,sup",
    "width"  : "87%",
    "height" : "300px"
}

# if True find FIRST the settings in the database table application.settings
# if False bypass the db table settings and search the property FIRST in local_settings
USE_DB_SETTINGS = True

# jogging settings
GLOBAL_LOG_LEVEL = logging.ERROR
GLOBAL_LOG_HANDLERS = [DatabaseHandler()]

#INCLUDE_USERPROFILE_URLS = True
DEFAULT_OPENOFFICE_PORT = 8100

REGISTRATION_DEFAULT_BACKEND = 'registration.backends.default.DefaultBackend'

SITE_MAINTENANCE = False
SITE_MAINTENANCE_DISABLE_FOR_SUPERUSER = False
SITE_MAINTENANCE_DISABLE_FOR_USERS = []
