from django.contrib.admin import widgets as admin_widgets
from django.db import models
from cms.plugins.text.widgets.tinymce_widget import TinyMCEEditor


class CMSHTMLField(models.TextField):
    """
    A large string field for HTML content. It uses the TinyMCE widget in
    forms.
    """
    
    def __init__(self, width=800):
        self.width = width  
        super(CMSHTMLField, self).__init__()
    
    def formfield(self, **kwargs):

        defaults = {'widget': TinyMCEEditor}
        defaults.update(kwargs)

        # As an ugly hack, we override the admin widget
        if defaults['widget'] == admin_widgets.AdminTextareaWidget:
            defaults['widget'] = TinyMCEEditor(mce_attrs={'width':'%spx' %self.width })

        return super(CMSHTMLField, self).formfield(**defaults)
