import sys
from optparse import make_option

from django.core.management.base import BaseCommand
from django.db.models import get_models, get_app
from django.contrib.auth.models import Permission, Group
from django.contrib.auth.management import create_permissions, _get_all_permissions
from django.contrib.contenttypes.models import ContentType

def get_permissions(app, created_models, **kwargs):

    app_models = get_models(app)
    if not app_models:
        return
    for klass in app_models:
        ctype = ContentType.objects.get_for_model(klass)
        for codename, name in _get_all_permissions(klass._meta):
            p, created = Permission.objects.get_or_create(codename=codename, content_type__pk=ctype.id,
                defaults={'name': name, 'content_type': ctype})
            yield p

class Command(BaseCommand):
    args = '<app app ...>'
    help = 'create group for specified app'
    option_list = BaseCommand.option_list + (
#        make_option('-f', '--filename', help='Read filename instead of stdin'),
        make_option('-n', '--name', help='name of the group'),
        )
   

    def handle(self, *args, **options):
        if not options['name']:
            print sys.stderr, "User option --name"
            sys.exit(1)

        if not args:
            print sys.stderr, "Please specify an application name"
            sys.exit(1)
            
        app = get_app(args[0])
        model_list = get_models(app_mod=app)

        group, created = Group.objects.get_or_create(name=options['name'])
        for model in model_list:
            ctype = ContentType.objects.get_for_model(model)
            for codename, descr in _get_all_permissions(model._meta):
                print "%s in %s" % (codename, options['name'])
                group.permissions.add(Permission.objects.get(codename=codename,
                                                             content_type__pk=ctype.id))
        group.save()
