from django.template import Library, Node, resolve_variable, TemplateSyntaxError
from django import http

register = Library()

class AddParameters(Node):
    def __init__(self, vars):
        self.vars = vars

    def render(self, context):
        params = http.QueryDict(query_string=None, mutable=True)

        for i in range(0, len(self.vars), 2):
            key = self.vars[i].resolve(context)
            if key == '': key = self.vars[i]      
            value = self.vars[i+1].resolve(context)
            if value == '': value = self.vars[i+1]
            params[key] = value

        return '?%s' % params.urlencode()

def url_param(parser, token):
    """
    Add multiple parameters to current url

    Usage:
    {% url-param name1 value1 name2 value2 %}
    or
    {% url-param "name1" value1 "name2" value2 %}

    variable can be use inplace of names and values
    example: {% url-param "view" message.id %}
    """

    bits = token.contents.split(' ')
    if len(bits) < 2:
        raise TemplateSyntaxError, "'%s' tag requires atleast two arguments" % bits[0]

    if len(bits)%2 != 1:
        raise TemplateSyntaxError, "The arguments must be pairs"

    vars = [parser.compile_filter(bit) for bit in bits[1:]]
    return AddParameters(vars)
register.tag('url_param', url_param)

