# -*- coding: utf-8 -*-
'''
Created on 1/ago/2011

@author: simone cittadini
'''
import sys

from django.db import models
from django.db.models.query import QuerySet
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType

"""
Uso: aggiungere 'jumbo.apps.profile' alle installed app.
    ereditare SCProfiles in una classe di un'applicazione del progetto.
    usare tale classe come AUTH_PROFILE_MODULE nei settings del progetto.
"""


class SubclassingQuerySet(QuerySet):
    def __getitem__(self, k):
        result = super(SubclassingQuerySet, self).__getitem__(k)
        if isinstance(result, models.Model) :
            return result.as_specific()
        else :
            return result

    def __iter__(self):
        for item in super(SubclassingQuerySet, self).__iter__():
            yield item.as_specific()
            
class SCProfilesManager(models.Manager):
    def get_query_set(self):
        return SubclassingQuerySet(self.model)
    
class SCProfiles(models.Model):
    user = models.OneToOneField(User)
    
    def get_profili_specifici(self):
        return SCProfile.objects.filter(scprofiles=self)
    
    def add_profile(self, classname, classpath=None, fields_dict={}):
        """
        Aggiunge un tipo Profile, coi campi inizializzati
        da un dizionario nome_campo : valore
        """
        if isinstance(classname, str) and classpath:
            try:
                mod = __import__(classpath, globals(), locals(), [classname])
                classe_profile = getattr(mod, classname)
            except:
                raise ImportError
        else:
            classe_profile = classname
        if issubclass(classe_profile, SCProfile):
            o = classe_profile(scprofiles=self)
            for field_name in fields_dict.keys():
                try:
                    setattr(o, field_name, fields_dict[field_name])
                except Exception, e:
                    print >> sys.stderr, "Exception in add_profile, can't set attribute: %s" % field_name
            o.save()
            return o
        else:
            raise TypeError
    
    def remove_profile(self, classname, classpath=None):
        if isinstance(classname, str) and classpath:
            try:
                mod = __import__(classpath, globals(), locals(), [classname])
                classe_profile = getattr(mod, classname)
            except:
                raise Exception("non trovo la classe")
        else:
            classe_profile = classname
        if issubclass(classe_profile, SCProfile):
            o = classe_profile.objects.get(scprofiles=self)
            o.delete()
        else:
            raise TypeError
        
    def get_profile(self, classname, classpath=None):
        if isinstance(classname, str) and classpath:
            try:
                mod = __import__(classpath, globals(), locals(), [classname])
                classe_profile = getattr(mod, classname)
            except:
                raise Exception("non trovo la classe")
        else:
            classe_profile = classname
        if issubclass(classe_profile, SCProfile):
            o = classe_profile.objects.get(scprofiles=self)
            return o
        else:
            raise TypeError
            
    @staticmethod
    def create_user(*args, **kwargs):
        """
        Crea uno user e gli associa automaticamente un SCProfiles.
        """
        u = User.objects.create_user(*args, **kwargs)
        SCProfiles.objects.create(user=u)
        return u


class SCProfile(models.Model):
    content_type = models.ForeignKey(ContentType, editable=False, null=True)
    scprofiles = models.ForeignKey(SCProfiles)
    objects = SCProfilesManager()

    def save(self, *args, **kwargs):
        if not self.content_type:
            self.content_type = ContentType.objects.get_for_model(self.__class__)
        super(SCProfile, self).save(*args, **kwargs)

    def as_specific(self):
        content_type = self.content_type
        model = content_type.model_class()
        if(model == SCProfile):
            return self
        return model.objects.get(id=self.id)

    def get_profiles(self):
        return self.scprofiles

    def get_user(self):
        return self.scprofiles.user
    
    def get_fields(self):
        return [(field.name, field.value_to_string(self.as_specific())) for field in self.content_type.model_class()._meta.fields]

    
class SCProfileDummyUno(SCProfile):
    """
    Solo a scopo test.
    """
    dummy_field = models.CharField(max_length=32)
    
class SCProfileDummyDue(SCProfile):
    """
    Solo a scopo test.
    """
    dummy_field = models.IntegerField()
